local L = LibStub("AceLocale-3.0"):GetLocale("Protwarbar")
local media = LibStub("LibSharedMedia-3.0")

function PWBAuraBar:CreateOptions()

	local textures = media:List("statusbar")
	local fonts = media:List("font")
	local backgrounds = media:List("background")

	local abilities = PWBAuraBar:GenerateOptions()

	local options = {
		type = "group",
		name = "Aurabar",
		childGroups = "tab",
		args = {
			group1 = {
				name = L["General"],
				type = "group",
				order = 1,
				args = {
					enable = {
					  	order = 1,
					  	name = L["Enable"],
					  	desc = L["Enable"],
					  	type = "toggle",
					  	set = function(info,val) self.db.enabled = val Protwarbar:RefreshConfig() end,
					  	get = function(info) return self.db.enabled end
					},
				},
			},
			group2 = {
				name = L["Position"],
				type = "group",
				order = 2,
				args = {
					desc_pos = {
						type = 'header',
						name = L["Position"],
						order = 1,
					},
					x = {
						order = 3,
						name = "X",
						desc = "X",
						type = "range",
						min = 1,
						max = 2560,
						step = 1,
						set = function(info,val) self.db.x = val Protwarbar:RefreshConfig() end,
						get = function(info) return self.db.x end
					},
					y = {
						order = 3,
						name = "Y",
						desc = "Y",
						type = "range",
						min = 1,
						max = 2048,
						step = 1,
						set = function(info,val) self.db.y = val Protwarbar:RefreshConfig() end,
						get = function(info) return self.db.y end
					},
					desc_6 = {
						type = 'description',
						name = " ",
						order = 6,
					},
					width = {
						order = 7,
						name = L["Width"],
						desc = L["Width of bar"],
						type = "range",
						min = 5,
						max = 750,
						step = 1,
						set = function(info,val) self.db.width = val Protwarbar:RefreshConfig() end,
						get = function(info) return self.db.width end
					},
					height = {
						order = 8,
						name = L["Height"],
						desc = L["Height of bar"],
						type = "range",
						min = 5,
						max = 750,
						step = 1,
						set = function(info,val) self.db.height = val Protwarbar:RefreshConfig() end,
						get = function(info) return self.db.height end
					},
				}
			},
			group4 = {
				name = L["Appearance"],
				type = "group",
				order = 4,
				args = {
					enable = {
						order = 1,
						name = L["Use defaults"],
						desc = L["Use defaults"],
						type = "toggle",
						set = function(info,val) self.db.useDefaults = val Protwarbar:RefreshConfig() end,
						get = function(info) return self.db.useDefaults end
					},
					desc_2 = {
						type = 'description',
						name = " ",
						order = 2,
					},
					reverse = {
					  order = 10,
					  name = L["Reverse"],
					  desc = L["Reverse the way the bar fills up"],
					  type = "toggle",
					  disabled = function() return self.db.useDefaults == true end,
					  set = function(info,val) self.db.reverse = val Protwarbar:RefreshConfig() end,
					  get = function(info) return self.db.reverse end
					},
					orient = {
						order = 11,
						name = L["Orientation"],
						desc = L["Orientation"],
						type = "select",
						disabled = function() return self.db.useDefaults == true end,
						values = function()
							orientations = {
								["HORIZONTAL"] = "Horizontal",
								["VERTICAL"] = "Vertical",
							}
							return orientations
						end,
						set = function(info, v)
								self.db.orientation = v
								Protwarbar:RefreshConfig()
							end,
						get = function(info) return self.db.orientation end
					},
					desc_bg_head = {
						type = 'header',
						name = L["Bar background"],
						order = 31,
					},
					barTexture = {
						name = L["Texture"],
						desc = L["Texture for ragebar"],
						type = "select",
						disabled = function() return self.db.useDefaults == true end,
						values = textures,
						order = 34,
						width = "normal",
						set = function(info, v)
								self.db.barTexture = media:List("statusbar")[v]
								Protwarbar:RefreshConfig()
							end,
						get = function(info) return GetLSMIndex("statusbar", self.db.barTexture) end
					},
					bg = {
						name = L["Background color"],
						desc = L["Color of bar Background"],
						type = "color",
						disabled = function() return self.db.useDefaults == true end,
						order = 33,
						width = "normal",
						hasAlpha = true,
						set = function(info, r, g, b, a)
								self.db.background[1] = r;
								self.db.background[2] = g;
								self.db.background[3] = b;
								self.db.background[4] = a;
								Protwarbar:RefreshConfig()
								end,
						get = function(info) return self.db.background[1], self.db.background[2],
													self.db.background[3], self.db.background[4]
							end
					},
				}
			},
			group3 = {
				name = L["Auras"],
				type = "group",
				order = 3,
				childGroups = "tree",
				args = abilities
			}
		}
	}
	return options
end


function PWBAuraBar:GenerateOptions()
	options = {}

	for id, ability in pairs(self.auraList) do
		options[tostring(id)] = PWBAuraBar:GenerateAbiltyOptions(ability, id)
	end

	return options
end

function PWBAuraBar:GenerateAbiltyOptions(ability, id)
	local options = {
		name = GetSpellInfo(id),
		type = "group",
		order = 4,
		args = {
			enable = {
				order = 1,
				name = L["Enable"],
				desc = L["Enables / disables the addon"],
				type = "toggle",
				set = function(info,val) self.db.auras[id].enabled = val Protwarbar:RefreshConfig() end,
				get = function(info) return self.db.auras[id].enabled end
			},
			bg = {
				name = L["Background color"],
				desc = L["Color of bar Background"],
				type = "color",
				order = 33,
				width = "normal",
				hasAlpha = true,
				set = function(info, r, g, b, a)
						self.db.auras[id].color[1] = r;
						self.db.auras[id].color[2] = g;
						self.db.auras[id].color[3] = b;
						self.db.auras[id].color[4] = a;
						Protwarbar:RefreshConfig()
						end,
				get = function(info) return self.db.auras[id].color[1], self.db.auras[id].color[2],
											self.db.auras[id].color[3], self.db.auras[id].color[4]
					end
			},
		}
	}

	return options

end