function PWBIcon:OnInitialize()
	self.db = Protwarbar.db.profile.PWBIcon

	self.iconList = {}
	self.activeIcons = {}
	self.activeRageIcons = {}
	self.activeDebuffIcons = {}

	self.iconFrames = {}
	self.iconCooldown = {}
	self.cdTable = {}
end

function PWBIcon:OnEnable()
	self:RegisterEvent("SPELL_UPDATE_COOLDOWN")
	self:RegisterEvent("UNIT_POWER_FREQUENT")
	self:RegisterEvent("PLAYER_TARGET_CHANGED")
	self:RegisterEvent("UNIT_AURA")
end

function PWBIcon:ProfileChanged()
	self.db = Protwarbar.db.profile.PWBIcon
end

function PWBIcon:RefreshConfig()

	-- reset active icons and cd's
	self.activeIcons = {}
	self.activeRageIcons = {}
	self.activeDebuffIcons = {}

	self.cdTable = {}

	for id, ability in pairs(self.iconList) do
		PWBIcon:AddOrCreate(id)

		self.iconList[id] = PWBIcon:UpdateMetaData(ability, id)
		PWBIcon:UpdateIconStyling(id)
		PWBIcon:UpdateIconVisiblity(id)
	end

	PWBIcon:UpdateRage(UnitPower("player"))
end

function PWBIcon:AddIcon(ability, id)

	ability = PWBIcon:UpdateMetaData(ability, id)

	table.insert(self.iconList, id, ability)

	PWBIcon:AddOrCreate(id)

	self.iconFrames[id] = PWBIcon:createIcon(ability, id)
	self.iconCooldown[id] = CreateFrame("Cooldown", nil ,self.iconFrames[id])
	self.iconCooldown[id]:SetAllPoints(self.iconFrames[id])

	PWBIcon:UpdateIconStyling(id)
	PWBIcon:UpdateIconVisiblity(id)
end

-- Store meta info in the table, so we can directly lookit up later on
function PWBIcon:UpdateMetaData(ability, id)
	ability.name = GetSpellInfo(id)

	if self.db.icons[id].useDefaults ~= nil then
		if self.db.icons[id].useDefaults then
			ability.hideOnCD = Protwarbar.db.profile.default.appearence.hideOnCD
			ability.lowRageAlpha = Protwarbar.db.profile.default.appearence.lowRageAlpha
		else
			ability.hideOnCD = self.db.icons[id].hideOnCD
			ability.lowRageAlpha = self.db.icons[id].lowRageAlpha
		end

	else
		ability.hideOnCD = Protwarbar.db.profile.default.appearence.hideOnCD
		ability.lowRageAlpha = Protwarbar.db.profile.default.appearence.lowRageAlpha
	end



	return ability
end


function PWBIcon:AddOrCreate(id)
	if self.db.icons[id] == nil then
		PWBIcon:InitNewIcon(id)
	end

	if self.db.icons[id].enabled then
		if self.iconList[id].talent == nil then
			PWBIcon:AddActiveIcon(id)
		else
			if Protwarbar.talents[self.iconList[id].talent] then
				PWBIcon:AddActiveIcon(id)
			end
		end
	end
end

function PWBIcon:AddActiveIcon(id)
	if self.iconList[id].rage ~= nil then
		table.insert(self.activeRageIcons, id)
	end

	if self.iconList[id].debuff == nil then
		table.insert(self.activeIcons, id)
		table.insert(self.cdTable, id, {0, 0})
	else
		table.insert(self.activeDebuffIcons, id)
	end

end

function PWBIcon:InitNewIcon(id)
	self.db.icons[id] = {}
	self.db.icons[id].x = self.db.startx
	self.db.icons[id].y = self.db.starty
	self.db.icons[id].useDefaults = true

	if self.iconList[id].enabled == true then
		self.db.icons[id].enabled = true
	else
		self.db.icons[id].enabled = false
	end
end

function PWBIcon:Update()
	for index, id in pairs(self.activeIcons) do
		PWBIcon:UpdateCooldown(id, self.iconFrames[id], self.iconCooldown[id], self.cdTable[id])
	end
end

function PWBIcon:UpdateCooldown(id, frame, cooldown, cdtable)
	local start, duration, enabled = GetSpellCooldown(id);

	if cdtable[1] ~= start or cdtable[2] ~= duration then
		cdtable[1] = start
		cdtable[2] = duration

		if self.iconList[id].hideOnCD then
			if duration > 1.5 then
				frame.texture:SetAlpha(0)
			else
				frame.texture:SetAlpha(1)
			end
		else
			CooldownFrame_SetTimer(cooldown, start, duration, 1)
		end
	end
end

function PWBIcon:UpdateRage(rage)
	for index, id in pairs(self.activeRageIcons) do
		if rage < self.iconList[id].rage then
			self.iconFrames[id].texture:SetAlpha(self.iconList[id].lowRageAlpha)
		else
			self.iconFrames[id].texture:SetAlpha(1)
		end
	end
end

function PWBIcon:UpdateDebufIcons()
	for index, id in pairs(self.activeDebuffIcons) do
		local n,_,_,_,_,d,e,_,_,_,sid,_,_,val1,val2,val3 = UnitAura("target", self.iconList[id].name, nil, "HARMFUL");

		if n then
			local duration = d or 0
			if d > 0 then
				CooldownFrame_SetTimer(self.iconCooldown[id], e-d, d, 1)
			end
		else
			CooldownFrame_SetTimer(self.iconCooldown[id], 1, 1, 1)
		end
	end
end

function PWBIcon:SPELL_UPDATE_COOLDOWN()
	PWBIcon:Update()
end

function PWBIcon:UNIT_POWER_FREQUENT(eventName, unit, powerType)
	if (unit == "player") then
		PWBIcon:UpdateRage(UnitPower("player"))
	end
end

function PWBIcon:PLAYER_TARGET_CHANGED()
	PWBIcon:UpdateDebufIcons()
end

function PWBIcon:UNIT_AURA(eventName, unit)
	if (unit == "target") then
		PWBIcon:UpdateDebufIcons()
	end
end