local L = LibStub("AceLocale-3.0"):GetLocale("Protwarbar")

local media = LibStub("LibSharedMedia-3.0")
local borders = media:List("border")

function PWBIcon:CreateOptions()

	local textures = media:List("statusbar")
	local fonts = media:List("font")
	local backgrounds = media:List("background")

	local abilities = PWBIcon:GenerateOptions()

	local options = {
		type = "group",
		name = "Protwarbar",
		childGroups = "tab",
		args = {
			group1 = {
				name = L["General"],
				type = "group",
				order = 1,
				args = {
					enable = {
					  	order = 1,
					  	name = L["Enable"],
					  	desc = L["Enable"],
					  	type = "toggle",
					  	set = function(info,val) self.db.enabled = val Protwarbar:RefreshConfig() end,
					  	get = function(info) return self.db.enabled end
					},
				},
			},
			group2 = {
				name = L["Icons"],
				type = "group",
				order = 1,
				childGroups = "tree",
				args = abilities
			},
		}
	}

	return options
end

function PWBIcon:GenerateOptions()
	options = {}

	for id, ability in pairs(self.iconList) do
		options[tostring(id)] = PWBIcon:GenerateAbiltyOptions(ability, id)
	end

	return options
end

function PWBIcon:GenerateAbiltyOptions(ability, id)

	iconalphaOptions = nil

	if ability.rage ~= nil then
		iconalphaOptions = {
			order = 32,
			name = L["Icon lack rage of alpha"],
			desc = L["Alpha for a spell that you don't have enough rage for at that moment"],
			type = "range",
			disabled = function() return self.db.icons[id].useDefaults == true end,
			min = 0,
			max = 1,
			step = 0.01,
			set = function(info,val) self.db.icons[id].lowRageAlpha = val Protwarbar:RefreshConfig() end,
			get = function(info)
				if self.db.icons[id].lowRageAlpha == nil then
					return Protwarbar.db.profile.default.appearence.lowRageAlpha
				else
					return self.db.icons[id].lowRageAlpha
				end
			end
		}
	end


	local options = {
		name = GetSpellInfo(id),
		type = "group",
		order = 4,
		args = {
			enable = {
				order = 1,
				name = L["Enable"],
				desc = L["Enables / disables the addon"],
				type = "toggle",
				set = function(info,val) self.db.icons[id].enabled = val Protwarbar:RefreshConfig() end,
				get = function(info) return self.db.icons[id].enabled end
			},
			desc_pos = {
				type = 'header',
				name = L["Position"],
				order = 4,
			},
			x = {
				order = 5,
				name = "X",
				desc = "X",
				type = "range",
				min = 1,
				max = 2560,
				step = 1,
				set = function(info,val) self.db.icons[id].x = val Protwarbar:RefreshConfig() end,
				get = function(info) return self.db.icons[id].x end
			},
			y = {
				order = 6,
				name = "Y",
				desc = "Y",
				type = "range",
				min = 1,
				max = 2048,
				step = 1,
				set = function(info,val) self.db.icons[id].y = val Protwarbar:RefreshConfig() end,
				get = function(info) return self.db.icons[id].y end
			},
			desc_app = {
				type = 'header',
				name = L["Appearance"],
				order = 11,
			},
			defaults = {
				order = 12,
				name = L["Use defaults"],
				desc = L["Use defaults"],
				type = "toggle",
				set = function(info,val) self.db.icons[id].useDefaults = val Protwarbar:RefreshConfig() end,
				get = function(info)
						if self.db.icons[id].useDefaults == nil then
							return true
						else
							return self.db.icons[id].useDefaults
						end
					end
			},
			desc_13 = {
				type = 'description',
				name = " ",
				order = 13,
			},
			size = {
				order = 21,
				name = L["Size"],
				desc = L["Size of the icons"],
				type = "range",
				disabled = function() return self.db.icons[id].useDefaults == true end,
				min = 5,
				max = 100,
				step = 1,
				set = function(info,val) self.db.icons[id].iconsize = val Protwarbar:RefreshConfig() end,
				get = function(info)
						if self.db.icons[id].iconsize == nil then
							return Protwarbar.db.profile.default.appearence.iconsize
						else
							return self.db.icons[id].iconsize
						end
					end
			},
			tsize = {
				order = 22,
				name = L["Texture Size"],
				desc = L["Texture Size"],
				type = "range",
				disabled = function() return self.db.icons[id].useDefaults == true end,
				min = 1,
				max = 100,
				step = 1,
				set = function(info,val) self.db.icons[id].textureSize = val Protwarbar:RefreshConfig() end,
				get = function(info)
						if self.db.icons[id].textureSize == nil then
							return Protwarbar.db.profile.default.appearence.textureSize
						else
							return self.db.icons[id].textureSize
						end
					end
			},
			border = {
				name = L["Border"],
				desc = L["Border"],
				type = "select",
				disabled = function() return self.db.icons[id].useDefaults == true end,
				values = borders,
				order = 26,
				width = "normal",
				set = function(info, v)
						self.db.icons[id].border = media:List("border")[v]
						Protwarbar:RefreshConfig()
					end,
				get = function(info)
						if self.db.border == nil then
							return GetLSMIndex("border", Protwarbar.db.profile.default.appearence.border)
						else
							return GetLSMIndex("border", self.db.icons[id].border)
						end
					end
			},
			edge = {
				order = 27,
				name = L["Edge size"],
				desc = L["Edge size"],
				type = "range",
				disabled = function() return self.db.icons[id].useDefaults == true end,
				min = 1,
				max = 50,
				step = 1,
				set = function(info,val) self.db.icons[id].edgeSize = val Protwarbar:RefreshConfig() end,
				get = function(info)
						if self.db.icons[id].edgeSize == nil then
							return Protwarbar.db.profile.default.appearence.edgeSize
						else
							return self.db.icons[id].edgeSize
						end
					end
			},
			iconalpha = iconalphaOptions,
			desc_31 = {
				type = 'description',
				name = " ",
				order = 41,
			},
			hideoncd = {
				order = 52,
				name = L["Hide on cooldown"],
				desc = L["Hide on cooldown"],
				type = "toggle",
				disabled = function() return self.db.icons[id].useDefaults == true end,
				set = function(info,val) self.db.icons[id].hideOnCD = val Protwarbar:RefreshConfig() end,
				get = function(info) return self.db.icons[id].hideOnCD end
			},
		}
	}

	return options
end

function GetLSMIndex(t, value)
	local media = LibStub("LibSharedMedia-3.0")

	for k, v in pairs(media:List(t)) do
		if v == value then
			return k
		end
	end
	return nil
end