function PWBInfo:CreateOptions()
	local L = LibStub("AceLocale-3.0"):GetLocale("Protwarbar")
	local media = LibStub("LibSharedMedia-3.0")
	local fonts = media:List("font")

	local options = {
		type = "group",
		name = "Information",
		childGroups = "tab",
		args = {
			group1 = {
				name = L["General"],
				type = "group",
				order = 1,
				args = {
					enable = {
					  order = 1,
					  name = L["Enable"],
					  desc = L["Enable the information frame"],
					  type = "toggle",
					  set = function(info,val) self.db.enabled = val Protwarbar:RefreshConfig() end,
					  get = function(info) return self.db.enabled end
					},
					desc_420 = {
						type = 'header',
						name = L["Information elements"],
						order = 20,
					},
					enableven = {
					  order = 21,
					  name = L["Display Vengeance"],
					  desc = L["Display Vengeance"],
					  type = "toggle",
					  set = function(info, val) self.db.vengeance.enabled = val Protwarbar:RefreshConfig() end,
					  get = function(info) return self.db.vengeance.enabled end
					},
					enablesb = {
					  order = 22,
					  name = L["Display Shield Barrier"],
					  desc = L["Display Shield Barrier"],
					  type = "toggle",
					  set = function(info, val) self.db.shieldBarrier.enabled = val Protwarbar:RefreshConfig() end,
					  get = function(info) return self.db.shieldBarrier.enabled end
					},
					seperator = {
						order = 30,
						name = L["Seperator"],
						desc = L["Seperator"],
						type = "input",
						set = function(info, val) self.db.seperator = val end,
						get = function(info) return self.db.seperator end
					},
				},
			},
			group2 = {
				name = L["Position"],
				type = "group",
				order = 2,
				args = {
					desc_pos = {
						type = 'header',
						name = L["Position"],
						order = 2,
					},
					x = {
						order = 4,
						name = "X",
						desc = "X",
						type = "range",
						min = 1,
						max = 2560,
						step = 1,
						set = function(info,val) self.db.x = val Protwarbar:RefreshConfig() end,
						get = function(info) return self.db.x end
					},
					you = {
						order = 5,
						name = "Y",
						desc = "Y",
						type = "range",
						min = 1,
						max = 2048,
						step = 1,
						set = function(info,val) self.db.y = val Protwarbar:RefreshConfig() end,
						get = function(info) return self.db.y end
					},
					desc_6 = {
						type = 'description',
						name = " ",
						order = 6,
					},
					venwidth = {
						order = 7,
						name = L["Width"],
						desc = L["Width of information frame"],
						type = "range",
						min = 5,
						max = 200,
						step = 1,
						set = function(info,val) self.db.width = val Protwarbar:RefreshConfig() end,
						get = function(info) return self.db.width end
					},
					venheight = {
						order = 8,
						name = L["Height"],
						desc = L["Height of information frame"],
						type = "range",
						min = 5,
						max = 200,
						step = 1,
						set = function(info,val) self.db.height = val Protwarbar:RefreshConfig() end,
						get = function(info) return self.db.height end
					},
				},
			},
			group3 = {
				name = L["Appearance"],
				type = "group",
				order = 3,
				args = {
					enable = {
						order = 1,
						name = L["Use defaults"],
						desc = L["Use defaults"],
						type = "toggle",
						set = function(info,val) self.db.useDefaults = val Protwarbar:RefreshConfig() end,
						get = function(info) return self.db.useDefaults end
					},
					desc_ven_head = {
						type = 'header',
						name = L["Information text"],
						order = 10,
					},
					venFont = {
						name = L["Font"],
						desc = L["Font for information"],
						type = "select",
						disabled = function() return self.db.useDefaults == true end,
						values = fonts,
						order = 11,
						set = function(info, v)
								self.db.font = media:List("font")[v]
								Protwarbar:RefreshConfig()
							end,
						get = function(info) return GetLSMIndex("font", self.db.font) end
					},
					desc_412 = {
						type = 'description',
						name = " ",
						order = 12,
					},
					venfontsize = {
						order = 13,
						name = L["Font Size"],
						desc = L["Size of the font used for information"],
						type = "range",
						disabled = function() return self.db.useDefaults == true end,
						min = 3,
						max = 50,
						step = 1,
						set = function(info,val) self.db.fontsize = val Protwarbar:RefreshConfig() end,
						get = function(info) return self.db.fontsize end
					},
					desc_bg = {
						type = 'header',
						name = L["Background"],
						order = 21,
					},
					bg = {
						name = L["Background color"],
						desc = L["Color of bar Background"],
						type = "color",
						disabled = function() return self.db.useDefaults == true end,
						order = 22,
						width = "normal",
						hasAlpha = true,
						set = function(info, r, g, b, a)
								self.db.background[1] = r;
								self.db.background[2] = g;
								self.db.background[3] = b;
								self.db.background[4] = a;
								Protwarbar:RefreshConfig()
								end,
						get = function(info) return self.db.background[1], self.db.background[2],
													self.db.background[3], self.db.background[4]
							end
					},
				},
			},

		}
	}

	return options

end